betty.ancestry.event_type package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.event_type package

## Submodules

- betty.ancestry.event_type.event_types module
  - `Adoption`
  - `Baptism`
  - `BarMitzvah`
  - `BatMitzvah`
  - `Birth`
    - `Birth.comes_before()`
  - `Burial`
  - `Conference`
  - `Confirmation`
  - `Correspondence`
  - `CreatableDerivableEventType`
    - `CreatableDerivableEventType.may_create()`
  - `Cremation`
  - `Death`
    - `Death.comes_after()`
    - `Death.may_create()`
  - `DerivableEventType`
  - `Divorce`
    - `Divorce.comes_after()`
  - `DivorceAnnouncement`
    - `DivorceAnnouncement.comes_after()`
    - `DivorceAnnouncement.comes_before()`
  - `DuringLifeEventType`
    - `DuringLifeEventType.comes_after()`
    - `DuringLifeEventType.comes_before()`
  - `Emigration`
  - `EndOfLifeEventType`
  - `Engagement`
    - `Engagement.comes_before()`
  - `FinalDispositionEventType`
  - `Funeral`
  - `Immigration`
  - `Marriage`
  - `MarriageAnnouncement`
    - `MarriageAnnouncement.comes_before()`
  - `Missing`
  - `Occupation`
  - `PostDeathEventType`
    - `PostDeathEventType.comes_after()`
  - `PreBirthEventType`
    - `PreBirthEventType.comes_before()`
  - `Residence`
  - `Retirement`
  - `StartOfLifeEventType`
  - `Unknown`
  - `Will`

## Module contents

Provide Betty’s ancestry event types.

betty.ancestry.event_type.EVENT_TYPE_REPOSITORY: PluginRepository[EventType] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The event type plugin repository.

  Read more about Event type plugins.

class betty.ancestry.event_type.EventType

  Bases: `OrderedPlugin`[`EventType`]

  Define an `betty.ancestry.event.Event` type.

  Read more about Event type plugins.

  To test your own subclasses, use `betty.test_utils.ancestry.event_type.EventTypeTestBase`.